@@ -1,12 +1,10 @@
 import django
 from django import forms
 from django.db import models
-from django.core.exceptions import ImproperlyConfigured, ValidationError
-from django.db.models.fields import FieldDoesNotExist
+from django.core.exceptions import ImproperlyConfigured, ValidationError, FieldDoesNotExist
 from django.forms.models import ModelChoiceIterator
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.functional import Promise
-from django.utils import six
 try:
     from django.db.models.fields.related import lazy_related_operation
 except ImportError:
@@ -172,7 +170,7 @@ class ModelMultipleChoiceField(Select2ModelFieldMixin, SortedMultipleChoiceField
         elif not self.required and not value:
             return []
 
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             value = value.split(',')
 
         if not isinstance(value, (list, tuple)):
@@ -188,14 +186,14 @@ class ModelMultipleChoiceField(Select2ModelFieldMixin, SortedMultipleChoiceField
         qs = self.queryset.filter(**{
             ('%s__in' % key): value,
         })
-        pks = set([force_text(getattr(o, key)) for o in qs])
+        pks = set([force_str(getattr(o, key)) for o in qs])
 
         # Create a dictionary for storing the original order of the items
         # passed from the form
         pk_positions = {}
 
         for i, val in enumerate(value):
-            pk = force_text(val)
+            pk = force_str(val)
             if pk not in pks:
                 raise ValidationError(self.error_messages['invalid_choice'] % val)
             pk_positions[pk] = i
@@ -209,7 +207,7 @@ class ModelMultipleChoiceField(Select2ModelFieldMixin, SortedMultipleChoiceField
             sort_value_field_name = self.sort_field.name
             objs = []
             for i, obj in enumerate(qs):
-                pk = force_text(getattr(obj, key))
+                pk = force_str(getattr(obj, key))
                 setattr(obj, sort_value_field_name, pk_positions[pk])
                 objs.append(obj)
             return sorted(objs, key=lambda obj: getattr(obj, sort_value_field_name))
@@ -273,7 +271,7 @@ class RelatedFieldMixin(object):
                     'field_name': self.name,
                     'app_label': self.model._meta.app_label,
                     'object_name': self.model._meta.object_name})
-        if not callable(self.search_field) and not isinstance(self.search_field, six.string_types):
+        if not callable(self.search_field) and not isinstance(self.search_field, str):
             raise TypeError(
                 ("keyword argument 'search_field' must be either callable or "
                  "string on field '%(field_name)s' of model "
@@ -281,7 +279,7 @@ class RelatedFieldMixin(object):
                     'field_name': self.name,
                     'app_label': self.model._meta.app_label,
                     'object_name': self.model._meta.object_name})
-        if isinstance(self.search_field, six.string_types):
+        if isinstance(self.search_field, str):
             try:
                 opts = related.parent_model._meta
             except AttributeError:
@@ -354,7 +352,7 @@ class ManyToManyField(RelatedFieldMixin, SortedManyToManyField):
             def resolve_sort_field(field, model, cls):
                 model._sort_field_name = field.sort_value_field_name
                 field.sort_field = model._meta.get_field(field.sort_value_field_name)
-            if isinstance(compat_rel(self).through, six.string_types):
+            if isinstance(compat_rel(self).through, str):
                 compat_add_lazy_relation(cls, self, compat_rel(self).through, resolve_sort_field)
             else:
                 resolve_sort_field(self, compat_rel(self).through, cls)
