@@ -1,14 +1,11 @@
 import re
 
-from django.utils import six
-
-
 re_spaces = re.compile(r"\s+")
 
 
 def combine_css_classes(classes, new_classes):
     if not classes:
-        if isinstance(new_classes, six.string_types):
+        if isinstance(new_classes, str):
             return new_classes
         else:
             try:
@@ -16,7 +13,7 @@ def combine_css_classes(classes, new_classes):
             except TypeError:
                 return new_classes
 
-    if isinstance(classes, six.string_types):
+    if isinstance(classes, str):
         classes = set(re_spaces.split(classes))
     else:
         try:
@@ -24,7 +21,7 @@ def combine_css_classes(classes, new_classes):
         except TypeError:
             return classes
 
-    if isinstance(new_classes, six.string_types):
+    if isinstance(new_classes, str):
         new_classes = set(re_spaces.split(new_classes))
     else:
         try:
